@@ -5,9 +5,17 @@ import i18n
 
 from typing import List
 
-i18n.load_path.append(os.path.join(os.path.dirname(__file__), 'locale'))
+FOLDER = os.path.abspath(os.path.dirname(os.path.abspath(__file__)))
+if not FOLDER.rstrip(os.path.sep).endswith(f'text_explainability{os.path.sep}text_explainability'):
+    FOLDER = os.path.join(FOLDER, 'text_explainability')
+
+i18n.load_path.append(os.path.join(FOLDER, 'locale'))
+i18n.set('filename_format', '{locale}.{format}')
+i18n.set('file_format', 'json')
 i18n.set('locale', 'nl')
 i18n.set('fallback', 'en')
+i18n.set('skip_locale_root_data', True)
+i18n.resource_loader.init_json_loader()
 
 
 def translate_string(id: str) -> str:
@@ -19,7 +27,7 @@ def translate_string(id: str) -> str:
     Returns:
         str: String corresponding to locale.
     """
-    return i18n.t(f'lang.{id}')
+    return i18n.t(f'{id}')
 
 
 def translate_list(id: str, sep: str = ';') -> List[str]:
@@ -32,7 +40,7 @@ def translate_list(id: str, sep: str = ';') -> List[str]:
     Returns:
         List[str]: List corresponding to locale.
     """
-    return i18n.t(f'lang.{id}').split(sep)
+    return i18n.t(f'{id}').split(sep)
 
 
 def set_locale(locale: str) -> None:
